@@ -498,17 +498,24 @@ impl JobSet {
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug)]
+/// information on jobs that are executing and queued for a given job batch
 pub struct RemainingJobs {
+    /// the name of the job batch (batch_name in distribute-jobs.yaml config file)
     pub batch_name: String,
+    /// the names of the jobs that are remaining
     pub jobs_left: Vec<String>,
+    /// jobs that are currently being executed on compute nodes
     pub running_jobs: Vec<RunningJobDuration>,
 }
 
 #[derive(Clone, Debug)]
+/// handler for a job that is being executed on the server
 pub struct RunningJob {
+    /// name of the job being executed
     job_name: String,
     /// information on the node we are running on
     node_meta: NodeMetadata,
+    /// time when the job was allocatead to a compute node
     start_time: std::time::Instant,
 }
 
@@ -593,9 +600,12 @@ mod tests {
             None,
         );
 
-        let jgpu = config::python::Job::new("jgpu".into(), File::new_relative("some_path"), vec![], None);
-        let j1 = config::python::Job::new("j1".into(), File::new_relative("some_path"), vec![], None);
-        let j2 = config::python::Job::new("j2".into(), File::new_relative("some_path"), vec![], None);
+        let jgpu =
+            config::python::Job::new("jgpu".into(), File::new_relative("some_path"), vec![], None);
+        let j1 =
+            config::python::Job::new("j1".into(), File::new_relative("some_path"), vec![], None);
+        let j2 =
+            config::python::Job::new("j2".into(), File::new_relative("some_path"), vec![], None);
 
         let build = config::python::Initialize::new(
             config::common::File::new_relative("build_file"),
@@ -611,15 +621,17 @@ mod tests {
         let cpu_description = config::python::Description::new(build.clone(), vec![j1, j2]);
         let gpu_description = config::python::Description::new(build.clone(), vec![jgpu]);
 
-        let cpu_config = config::Jobs::from(config::PythonConfig::new(cpu_meta, cpu_description, None))
-            .hashed()
-            .unwrap()
-            .into();
+        let cpu_config =
+            config::Jobs::from(config::PythonConfig::new(cpu_meta, cpu_description, None))
+                .hashed()
+                .unwrap()
+                .into();
 
-        let gpu_config = config::Jobs::from(config::PythonConfig::new(gpu_meta, gpu_description, None))
-            .hashed()
-            .unwrap()
-            .into();
+        let gpu_config =
+            config::Jobs::from(config::PythonConfig::new(gpu_meta, gpu_description, None))
+                .hashed()
+                .unwrap()
+                .into();
 
         (cpu_config, gpu_config, scheduler)
     }
